#include <Adafruit_NeoPixel.h>
#include <Adafruit_GFX.h>
#include <Adafruit_NeoMatrix.h>
#include <Wire.h>
#include <MPU6050_light.h>

#define MATRIX_PIN 0
#define MATRIX_WIDTH 10
#define MATRIX_HEIGHT 10
#define NUMPIXELS (MATRIX_WIDTH * MATRIX_HEIGHT)

Adafruit_NeoMatrix matrix = Adafruit_NeoMatrix(MATRIX_WIDTH, MATRIX_HEIGHT, MATRIX_PIN,
  NEO_MATRIX_TOP + NEO_MATRIX_LEFT +
  NEO_MATRIX_ROWS,
  NEO_GRB + NEO_KHZ800);

MPU6050 mpu(Wire1);

int prevX = MATRIX_WIDTH / 2;
int prevY = MATRIX_HEIGHT / 2;

void setup() {
  matrix.begin();
  matrix.setBrightness(50);

  // Initialize I2C1 with pins 26 (SDA) and 27 (SCL)
  Wire1.setSDA(26);
  Wire1.setSCL(27);
  Wire1.begin();

  mpu.begin();
  mpu.calcOffsets(true, true); // Calculate and apply offsets

  // Display initialization success
  matrix.fillScreen(0);
  matrix.show();
}

void loop() {
  mpu.update();

  // Normalize accelerometer values
  float axNorm = -mpu.getAccX() * 5; // Invert X-axis sensitivity
  float ayNorm = mpu.getAccY() * 5; // Adjust sensitivity

  // Clear the previous pixel
  matrix.drawPixel(prevX, prevY, matrix.Color(0, 0, 0));

  // Calculate the new position
  int centerX = MATRIX_WIDTH / 2;
  int centerY = MATRIX_HEIGHT / 2;

  int newX = constrain(centerX + (int)ayNorm, 0, MATRIX_WIDTH - 1); // Horizontal movement
  int newY = constrain(centerY - (int)axNorm, 0, MATRIX_HEIGHT - 1); // Vertical movement

  // Update the matrix with the new position
  matrix.drawPixel(newX, newY, matrix.Color(255, 0, 0)); // Display influenced pixel
  matrix.show();
  
  // Update the previous position
  prevX = newX;
  prevY = newY;

  delay(20); // Reduce delay for smoother movement
}
